# Version History

## 0.8 2025-06-26

* Update for base_loom_server 0.24.
  (base_loom_server 0.19 will still work, but two unit tests will fail.)

## 0.7 2025-06-03

* Update for base_loom_server 0.19, which adds a Settings panel.
* Add this version history.

## 0.6.3 2025-03-31

Minor documentation fixes.

## 0.6.2 2025-03-18

Internal changes.

## 0.6.1 2025-03-15

Internal changes.

## 0.6.0 2025-03-14

The first release.
